[![pipeline status](https://git.fenrys.io/fenrys/back/python_ddd/badges/master/pipeline.svg)](https://git.fenrys.io/fenrys/back/python_ddd/commits/master)
[![coverage report](https://git.fenrys.io/fenrys/back/python_ddd/badges/master/coverage.svg)](https://git.fenrys.io/fenrys/back/python_ddd/commits/master)
# Description
Python project aimed to implement DDD and event sourcing
